@@ -1,32 +1,35 @@
+"""This is part of the MSS Python's module.
+Source: https://github.com/BoboTiG/python-mss.
 """
-This is part of the MSS Python's module.
-Source: https://github.com/BoboTiG/python-mss
-"""
+
+from __future__ import annotations
+
 import ctypes
 import ctypes.util
 import sys
 from ctypes import POINTER, Structure, c_double, c_float, c_int32, c_ubyte, c_uint32, c_uint64, c_void_p
 from platform import mac_ver
-from typing import Any, Optional, Type, Union
+from typing import TYPE_CHECKING, Any
 
-from .base import MSSBase
-from .exception import ScreenShotError
-from .models import CFunctions, Monitor
-from .screenshot import ScreenShot, Size
+from mss.base import MSSBase
+from mss.exception import ScreenShotError
+from mss.screenshot import ScreenShot, Size
+
+if TYPE_CHECKING:
+    from mss.models import CFunctions, Monitor
 
 __all__ = ("MSS",)
 
 
-def cgfloat() -> Union[Type[c_double], Type[c_float]]:
+def cgfloat() -> type[c_double | c_float]:
     """Get the appropriate value for a float."""
-
     return c_double if sys.maxsize > 2**32 else c_float
 
 
 class CGPoint(Structure):
     """Structure that contains coordinates of a rectangle."""
 
-    _fields_ = [("x", cgfloat()), ("y", cgfloat())]
+    _fields_ = (("x", cgfloat()), ("y", cgfloat()))
 
     def __repr__(self) -> str:
         return f"{type(self).__name__}(left={self.x} top={self.y})"
@@ -35,7 +38,7 @@ class CGPoint(Structure):
 class CGSize(Structure):
     """Structure that contains dimensions of an rectangle."""
 
-    _fields_ = [("width", cgfloat()), ("height", cgfloat())]
+    _fields_ = (("width", cgfloat()), ("height", cgfloat()))
 
     def __repr__(self) -> str:
         return f"{type(self).__name__}(width={self.width} height={self.height})"
@@ -44,7 +47,7 @@ class CGSize(Structure):
 class CGRect(Structure):
     """Structure that contains information about a rectangle."""
 
-    _fields_ = [("origin", CGPoint), ("size", CGSize)]
+    _fields_ = (("origin", CGPoint), ("size", CGSize))
 
     def __repr__(self) -> str:
         return f"{type(self).__name__}<{self.origin} {self.size}>"
@@ -52,13 +55,11 @@ class CGRect(Structure):
 
 # C functions that will be initialised later.
 #
-# This is a dict:
-#    cfunction: (attr, argtypes, restype)
-#
 # Available attr: core.
 #
 # Note: keep it sorted by cfunction.
 CFUNCTIONS: CFunctions = {
+    # cfunction: (attr, argtypes, restype)
     "CGDataProviderCopyData": ("core", [c_void_p], c_void_p),
     "CGDisplayBounds": ("core", [c_uint32], CGRect),
     "CGDisplayRotation": ("core", [c_uint32], c_float),
@@ -79,16 +80,14 @@ CFUNCTIONS: CFunctions = {
 
 
 class MSS(MSSBase):
-    """
-    Multiple ScreenShots implementation for macOS.
+    """Multiple ScreenShots implementation for macOS.
     It uses intensively the CoreGraphics library.
     """
 
     __slots__ = {"core", "max_displays"}
 
     def __init__(self, /, **kwargs: Any) -> None:
-        """macOS initialisations."""
-
+        """MacOS initialisations."""
         super().__init__(**kwargs)
 
         self.max_displays = kwargs.get("max_displays", 32)
@@ -106,12 +105,12 @@ class MSS(MSSBase):
             coregraphics = "/System/Library/Frameworks/CoreGraphics.framework/Versions/Current/CoreGraphics"
 
         if not coregraphics:
-            raise ScreenShotError("No CoreGraphics library found.")
+            msg = "No CoreGraphics library found."
+            raise ScreenShotError(msg)
         self.core = ctypes.cdll.LoadLibrary(coregraphics)
 
     def _set_cfunctions(self) -> None:
         """Set all ctypes functions and attach them to attributes."""
-
         cfactory = self._cfactory
         attrs = {"core": self.core}
         for func, (attr, argtypes, restype) in CFUNCTIONS.items():
@@ -119,7 +118,6 @@ class MSS(MSSBase):
 
     def _monitors_impl(self) -> None:
         """Get positions of monitors. It will populate self._monitors."""
-
         int_ = int
         core = self.core
 
@@ -147,7 +145,7 @@ class MSS(MSSBase):
                     "top": int_(rect.origin.y),
                     "width": int_(width),
                     "height": int_(height),
-                }
+                },
             )
 
             # Update AiO monitor's values
@@ -164,14 +162,13 @@ class MSS(MSSBase):
     def _grab_impl(self, monitor: Monitor, /) -> ScreenShot:
         """Retrieve all pixels from a monitor. Pixels have to be RGB."""
 
-        # pylint: disable=too-many-locals
-
         core = self.core
         rect = CGRect((monitor["left"], monitor["top"]), (monitor["width"], monitor["height"]))
 
         image_ref = core.CGWindowListCreateImage(rect, 1, 0, 0)
         if not image_ref:
-            raise ScreenShotError("CoreGraphics.CGWindowListCreateImage() failed.")
+            msg = "CoreGraphics.CGWindowListCreateImage() failed."
+            raise ScreenShotError(msg)
 
         width = core.CGImageGetWidth(image_ref)
         height = core.CGImageGetHeight(image_ref)
@@ -204,6 +201,6 @@ class MSS(MSSBase):
 
         return self.cls_image(data, monitor, size=Size(width, height))
 
-    def _cursor_impl(self) -> Optional[ScreenShot]:
+    def _cursor_impl(self) -> ScreenShot | None:
         """Retrieve all cursor data. Pixels have to be RGB."""
         return None
